@@ -5,6 +5,7 @@
 pub use self::kinds::PrimaryColor;
 pub use self::kinds::SecondaryColor;
 pub use self::utils::mix;
+pub use self::utils::mix_break;
 
 pub mod kinds {
     /// The primary colors according to the RYB color model.
@@ -31,4 +32,9 @@ pub mod utils {
         // --snip--
         SecondaryColor::Green
     }
+
+    pub fn mix_break(c1: PrimaryColor, c2: SecondaryColor) -> SecondaryColor {
+        // --snip--
+        SecondaryColor::Green
+    }
 }
